﻿using System;

using NUnit.Framework;


namespace RealLifeExample.Tests
{
    public class NameHelperTests
    {
        [TestFixture]
        public class GetUniqueNameTets
        {
            [Test]
            public void GetUniqueName_CustomersProblem_IsFixed()
            {
                var actual = NameHelper.GetUniqueName("aa", "bbbb", true, 3);
                var expected = "bbb";

                Assert.AreEqual(expected, actual);
            }

            [Test]
            public void GetUniqueName_Null_ReturnsNull()
            {
                var actual = NameHelper.GetUniqueName(null);

                Assert.AreEqual(String.Empty, actual);
                
            }

            [Test]
            public void GetUniqueName_NameExists_AddsNumber()
            {
                string name = "Karel";

                NameProvider.AddName(name);

                var expectedName = "Karel1";

                var actualName = NameHelper.GetUniqueName(name);

                Assert.AreEqual(expectedName, actualName, "Number suffix should have been added to the name.");
            }

            [Test]
            public void GetUniqueName_NameAndPrefix_PrefixAdded()
            {
                var actualName = NameHelper.GetUniqueName("Karel", "Mc");

                Assert.AreEqual("McKarel", actualName, "Prefix should have been added at the start of the name.");
            }

            [TearDown]
            public void TearDown()
            {
                NameProvider.ClearAllNames();
            }
        }
    }
}
