﻿using System;

namespace RealLifeExample
{
    /// <summary>
    /// Helper class for name manipulation.
    /// </summary>
    public class NameHelper
    {
        /// <summary>
        /// Maximum name length.
        /// </summary>
        private const int MAX_NAME_LENGTH = 50;

        /// <summary>
        /// Returns unique name from given plain text.
        /// </summary>
        /// <param name="prefix">Prefix of the name that should be used</param>
        /// <param name="plainText">Plain text from which the string should be generated</param>
        /// <param name="maxNameLength">Maximal resource name length</param>
        /// <param name="returnWithPrefix">Indicates whether return name with prefix</param>
        public static string GetUniqueName(string plainText, string prefix = "", bool returnWithPrefix = true, int maxNameLength = MAX_NAME_LENGTH)
        {
            if (maxNameLength <= 0)
            {
                maxNameLength = MAX_NAME_LENGTH;
            }

            string resKey = StringHelper.LimitLength(StringHelper.GetCodeName(plainText), maxNameLength, String.Empty, true);

            // If resource key is longer then allowed length then trim
            if (prefix.Length + resKey.Length > maxNameLength)
            {
                resKey = resKey.Substring(0, maxNameLength - prefix.Length);
            }

            int i = 1;
            while (!IsUniqueName(prefix + resKey))
            {
                // If newly created resource key is longer then allowed length then trim
                if (prefix.Length + resKey.Length + i.ToString().Length > maxNameLength)
                {
                    resKey = resKey.Substring(0, resKey.Length - prefix.Length - i.ToString().Length);
                }

                if (resKey.EndsWith((i - 1).ToString()))
                {
                    resKey = resKey.Substring(0, resKey.Length - (i - 1).ToString().Length);
                }

                resKey += i++;
            }

            return returnWithPrefix ? prefix + resKey : resKey;
        }

        /// <summary>
        /// Check if resource key is unique.
        /// </summary>
        /// <param name="resKey">Resource key</param>
        /// <param name="resPrefix">Resource prefix</param>
        private static bool IsUniqueName(string resKey, string resPrefix = "")
        {
            return NameProvider.GetName(resPrefix + resKey) == null;
        }
    }
}
