﻿using System;
using System.Collections.Generic;

namespace RealLifeExample
{
    /// <summary>
    /// Name provider
    /// </summary>
    public class NameProvider
    {
        private static HashSet<string> _names = new HashSet<string>();

        /// <summary>
        /// Add a new name.
        /// </summary>
        /// <param name="name">Name to be added</param>
        /// <exception cref="InvalidOperationException">Given name already exists.</exception>
        public static void AddName(string name)
        {
            if (!_names.Add(name))
            {
                throw new InvalidOperationException($"'{name}' already exists. Names must be unique!");
            }
        }

        /// <summary>
        /// Returns given name if it exists or <c>null</c> otherwise.
        /// </summary>
        /// <param name="name">Name to be retrieved</param>
        public static string GetName(string name)
        {
            return _names.Contains(name) ? name : null;
        }


        /// <summary>
        /// Removes all existing names.
        /// </summary>
        public static void ClearAllNames()
        {
            _names.Clear();
        }
    }
}
